<?php
namespace MASCOTCORENOVIO\Shortcodes\ParollerAnimation;

use MASCOTCORENOVIO\Shortcodes\Lib;

/**
 * class SC_Paroller_Animation
 * @package MASCOTCORENOVIO\Shortcodes\ParollerAnimation;
 */
class SC_Paroller_Animation implements Lib\Mascot_Core_Novio_Interface_Shortcodes {
	
	/**
	 * @var shortcode_base
	 */
	private $shortcode_base;

	/**
	 * construct
	 */
	public function __construct() {
		$this->shortcode_base = 'tm_paroller_animation';
		add_action('init', array($this, 'MapShortCodeVC'), 998);
	}

	/**
	 * Returns shortcode_base for shortcode
	 */
	public function getShortCodeBase() {
		return $this->shortcode_base;
	}

	/**
	 * Maps shortcode to Visual Composer
	 */
	public function MapShortCodeVC() {
		$group_styling_options = esc_html__( 'Text Options', 'mascot-core' );
		$paroller_options = esc_html__( 'Paroller Options', 'mascot-core' );
		$bgtext_options = esc_html__( 'Background Text Options', 'mascot-core' );
		$footer_cite_options = esc_html__( 'Footer Cite Options', 'mascot-core' );

		if(function_exists('vc_map')) {
			$vc_map = array(
				'name'		=> esc_html__( 'Paroller Animation', 'mascot-core' ),
				'base'		=>$this->shortcode_base,
				'category'	=> esc_html__( 'by TM', 'mascot-core' ),
				'icon'		=> 'mascot-vc-icons vc-icon-iconbox',
				'allowed_container_element' => 'vc_row',
				'params'	=>array(
					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Custom CSS class", 'mascot-core' ),
						"param_name"	=> "custom_css_class",
						"description"	=> esc_html__( 'To style particular content element.', 'mascot-core' ),
					),
					array(
						'type'			=> 'dropdown',
						"heading"		=> esc_html__( "Animation Type", 'mascot-core' ),
						"param_name"	=> "display_type",
						"description"	=> "",
						'value'			=> array(
							esc_html__( 'Text Layer', 'mascot-core-elementor' )	=>	'layer-text',
							esc_html__( 'Image Layer', 'mascot-core-elementor' )	=>	'layer-image',
							esc_html__( 'Both Text and Image Layers', 'mascot-core-elementor' )	=>	'layer-both',
						),
						'std'			=> 'layer-text',
					),

					array(
						'type'			=> 'attach_image',
						"heading"		=> esc_html__( "Paroller Parallax Image", 'mascot-core' ),
						"param_name"	=> "paroller_image",
						'save_always'   => true,
						'admin_label'   => true,
						'dependency'	=> array('element' => 'display_type', 'value' => array('layer-image', 'layer-both')),
					),
					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Paroller Parallax Text", 'mascot-core' ),
						"param_name"	=> "paroller_text",
						'save_always'   => true,
						'admin_label'   => true,
						'dependency'	=> array('element' => 'display_type', 'value' => array('layer-text', 'layer-both')),
					),
					array(
						'type'			=> 'checkbox',
						"heading"		=> esc_html__( "Enable Textillate Text Animation?", 'mascot-core' ),
						"param_name"	=> "text_textillate_animation",
						'description'	=> '',
						'std'			=> 'true',
						'save_always'   => true,
						'admin_label'   => true,
						'dependency'	=> array('element' => 'display_type', 'value' => array('layer-text', 'layer-both')),
					),
					array(
						'type'			=> 'checkbox',
						"heading"		=> esc_html__( "Show Stroke in Text?", 'mascot-core' ),
						"param_name"	=> "show_stroke_text",
						'description'   => '',
						'dependency'	=> array('element' => 'display_type', 'value' => array('layer-text', 'layer-both')),
					),
					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Text Stroke Size", 'mascot-core' ),
						"param_name"	=> "text_stroke_size",
						"description"	=> esc_html__( "Integer value between 1 to 30", 'mascot-core' ),
						'dependency'	=> array('element' => 'show_stroke_text', 'value' => array('true')),
					),
					array(
						'type'			=> 'dropdown',
						"heading"		=> esc_html__( "Floating Animation Type", 'mascot-core' ),
						"param_name"	=> "animation_type",
						'value'			=> mascot_core_novio_get_animation_type(),
						'save_always'   => true,
						'admin_label'   => true,
						'std'				=> '',
					),






					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Top (px or %)", 'mascot-core' ),
						"param_name"	=> "pos_top",
						'save_always'   => true,
						'admin_label'   => true,
						'group'			=> $group_styling_options,
					),
					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Right (px or %)", 'mascot-core' ),
						"param_name"	=> "pos_right",
						'save_always'   => true,
						'admin_label'   => true,
						'group'			=> $group_styling_options,
					),
					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Bottom (px or %)", 'mascot-core' ),
						"param_name"	=> "pos_bottom",
						'save_always'   => true,
						'admin_label'   => true,
						'group'			=> $group_styling_options,
					),
					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Left (px or %)", 'mascot-core' ),
						"param_name"	=> "pos_left",
						'save_always'   => true,
						'admin_label'   => true,
						'group'			=> $group_styling_options,
					),
					array(
						'type'			=> 'colorpicker',
						"heading"		=> esc_html__( "Text Color", 'mascot-core' ),
						"param_name"	=> "title_text_color",
						'description'	=> '',
						'group'			=> $group_styling_options,
					),
					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Font Size", 'mascot-core' ),
						"param_name"	=> "title_font_size",
						"description"	=> "",
						'group'			=> $group_styling_options
					),
					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Line Height", 'mascot-core' ),
						"param_name"	=> "title_line_height",
						"description"	=> "",
						'group'			=> $group_styling_options
					),
					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Letter Spacing", 'mascot-core' ),
						"param_name"	=> "title_letter_spacing",
						"description"	=> "",
						'group'			=> $group_styling_options
					),
					array(
						'type'			=> 'dropdown',
						"heading"		=> esc_html__( "Font Style", 'mascot-core' ),
						"param_name"	=> "title_font_style",
						"description"	=> "",
						'value'			=> mascot_core_novio_vc_font_style_list(),
						'group'			=> $group_styling_options
					),
					array(
						'type'			=> 'dropdown',
						"heading"		=> esc_html__( "Font Weight", 'mascot-core' ),
						"param_name"	=> "title_font_weight",
						"description"	=> "",
						'value'			=> mascot_core_novio_vc_font_weight_list(),
						'group'			=> $group_styling_options
					),
					array(
						'type'			=> 'dropdown',
						"heading"		=> esc_html__( "Text Transform", 'mascot-core' ),
						"param_name"	=> "title_text_transform",
						"description"	=> "",
						'value'			=> mascot_core_novio_vc_text_transform_list(),
						'group'			=> $group_styling_options
					),


					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Z Index", 'mascot-core' ),
						"param_name"	=> "z_index",
						'save_always'   => true,
						'admin_label'   => true,
						'group'			=> $group_styling_options
					),
					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Container Width (px or %)", 'mascot-core' ),
						"param_name"	=> "width",
						'save_always'   => true,
						'admin_label'   => true,
						'group'			=> $group_styling_options
					),
					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Container Height (px or %)", 'mascot-core' ),
						"param_name"	=> "height",
						'save_always'   => true,
						'admin_label'   => true,
						'group'			=> $group_styling_options
					),
					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Opacity", 'mascot-core' ),
						"param_name"	=> "opacity",
						"description"	=> esc_html__( 'Value between 0 to 1', 'mascot-core' ),
						'save_always'   => true,
						'admin_label'   => true,
						'group'			=> $group_styling_options
					),
					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Rotate", 'mascot-core' ),
						"param_name"	=> "rotate_text",
						"description"	=> esc_html__( 'Value between -90 to 90', 'mascot-core' ),
						'save_always'   => true,
						'admin_label'   => true,
						'group'			=> $group_styling_options
					),










					//Paroller Parallax
					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Paroller Factor", 'mascot-core' ),
						"param_name"	=> "paroller_factor",
						"description"	=> esc_html__( 'Multiplier for scrolling speed and offset. Example: 0.3 and 0 to stop.', 'mascot-core' ),
						'admin_label'   => true,
						'group'			=> $paroller_options,
					),
					array(
						'type'			=> 'dropdown',
						"heading"		=> esc_html__( "Paroller Type", 'mascot-core' ),
						"param_name"	=> "paroller_type",
						"value" => array(
							esc_html__( 'Foreground', 'mascot-core' )	=> 'foreground',
							esc_html__( 'Background', 'mascot-core' ) => 'background',
						) ,
						'admin_label'   => true,
						'group'			=> $paroller_options,
					),
					array(
						'type'			=> 'dropdown',
						"heading"		=> esc_html__( "Paroller Direction", 'mascot-core' ),
						"param_name"	=> "paroller_direction",
						"value" => array(
							esc_html__( 'Horizontal', 'mascot-core' )	=> 'horizontal',
							esc_html__( 'Vertical', 'mascot-core' ) => 'vertical',
						) ,
						'admin_label'   => true,
						'group'			=> $paroller_options,
					),
					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Paroller Transition", 'mascot-core' ),
						"param_name"	=> "paroller_transition",
						"description"	=> esc_html__( 'CSS transition. Example: transform .3s ease-out', 'mascot-core' ),
						'admin_label'   => true,
						'group'			=> $paroller_options,
					),
					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Parallax Text/Image Custom CSS class", 'mascot-core' ),
						"param_name"	=> "paroller_text_custom_css_class",
						'admin_label'   => true,
						'group'			=> $paroller_options,
					),
					array(
						'type'			=> 'textfield',
						"heading"		=> esc_html__( "Parallax Text/Image Custom Inline Style", 'mascot-core' ),
						"param_name"	=> "paroller_text_custom_inline_css",
						"description"	=> esc_html__( 'Example: color: #f1f1f1; font-size: 120px; line-height: 1; top: 12px; left: 100px', 'mascot-core' ),
						'admin_label'   => true,
						'group'			=> $paroller_options,
					),


					mascot_core_novio_vc_add_css_editor(),

				)
			);
			vc_map( $vc_map );

			//Modify vc_map from themes
			if( function_exists('mascot_core_novio_sc_paroller_animation_vc_map_modifier') ) {
				mascot_core_novio_sc_paroller_animation_vc_map_modifier( $this->shortcode_base );
			}
		}
	}

	/**
	 * Renders shortcodes HTML
	 */
	public function render( $attr, $content = null ) {

		//Render Shortcode from themes
		if( function_exists('mascot_core_novio_sc_paroller_animation_render') && function_exists('vc_map') ) {
			return mascot_core_novio_sc_paroller_animation_render( $attr, $content );
		}
	}
}